# Devops - Trabalho Final

Trabalho final da materia de Devops

## Execução do projeto

```
source automation/create.sh
```

## Excluir os diretorios e arquivos criados

```
source automation/remove.sh
```